# amap-python
Automated mouse atlas propagation


### About
amap is python software for registration of brain templates to sample whole-brain
microscopy datasets, and subsequent atlas-based segmentation by
[Adam Tyson](https://github.com/adamltyson), 
[Charly Rousseau](https://github.com/crousseau) & 
[Christian Niedworok](https://github.com/cniedwor) 
from the [Margrie Lab at the Sainsbury Wellcome Centre](https://www.sainsburywellcome.org/web/groups/margrie-lab).


This is a Python port of 
[aMAP](https://github.com/SainsburyWellcomeCentre/aMAP/wiki) (originally 
written in Java), which has been 
[validated against human segmentation](https://www.nature.com/articles/ncomms11879).


### Installation
```bash
pip install amap
```

### Usage
TBC. But [get in touch](mailto:adam.tyson@ucl.ac.uk?subject=amap) if you'd 
like to use it. Currently only the 2017 Allen Institute reference adult mouse
 brain atlas is supported (but others are planned).